@@ -10,12 +10,12 @@ import tabix
 
 # utils
 # simulate
-from polygenic.lib.data_access.vcf_accessor import VcfAccessor
-from polygenic.lib.data_access.vcf_accessor import DataNotPresentError
-from polygenic.lib.utils import is_valid_path
-from polygenic.lib.utils import download
-from polygenic.lib.utils import read_header
-from polygenic.lib.utils import read_table
+from polygenic.data.vcf_accessor import VcfAccessor
+from polygenic.data.vcf_accessor import DataNotPresentError
+from polygenic.core.utils import is_valid_path
+from polygenic.core.utils import download
+from polygenic.core.utils import read_header
+from polygenic.core.utils import read_table
 
 # clumping
 import subprocess
